==> bbctrl-1.0.1-rc11.tar.bz2: bbctrl-1.0.1/src/py/bbctrl/InputsPage.py <==
################################################################################
#                                                                              #
#                 This file is part of the Buildbotics firmware.               #
#                                                                              #
#        Copyright (c) 2015 - 2021, Buildbotics LLC, All rights reserved.      #
#                                                                              #
#         This Source describes Open Hardware and is licensed under the        #
#                                 CERN-OHL-S v2.                               #
#                                                                              #
#         You may redistribute and modify this Source and make products        #
#    using it under the terms of the CERN-OHL-S v2 (https:/cern.ch/cern-ohl).  #
#           This Source is distributed WITHOUT ANY EXPRESS OR IMPLIED          #
#    WARRANTY, INCLUDING OF MERCHANTABILITY, SATISFACTORY QUALITY AND FITNESS  #
#     FOR A PARTICULAR PURPOSE. Please see the CERN-OHL-S v2 for applicable    #
#                                  conditions.                                 #
#                                                                              #
#                Source location: https://github.com/buildbotics               #
#                                                                              #
#      As per CERN-OHL-S v2 section 4, should You produce hardware based on    #
#    these sources, You must maintain the Source Location clearly visible on   #
#    the external case of the CNC Controller or other product you make using   #
#                                  this Source.                                #
#                                                                              #
#                For more information, email info@buildbotics.com              #
#                                                                              #
################################################################################

import subprocess

import bbctrl


class InputsPage(bbctrl.LCDPage):
    # From bbctrl.LCDPage
    def activate(self):
        state = self.lcd.ctrl.state

        self.clear()

        self.text('0123', 5, 0)
        self.text('Min:', 0, 1)
        self.text('Max:', 0, 2)

        for i in range(4):
            minSwitch = state.get('min-switch-' + i)
            maxSwitch = state.get('max-switch-' + i)

            self.text(' ', 5 + i, 1)
            self.text(' ', 5 + i, 2)

==> bbctrl-1.0.4-rc12.tar.bz2: bbctrl-1.0.4/src/py/bbctrl/InputsPage.py <==
################################################################################
#                                                                              #
#                 This file is part of the Buildbotics firmware.               #
#                                                                              #
#        Copyright (c) 2015 - 2021, Buildbotics LLC, All rights reserved.      #
#                                                                              #
#         This Source describes Open Hardware and is licensed under the        #
#                                 CERN-OHL-S v2.                               #
#                                                                              #
#         You may redistribute and modify this Source and make products        #
#    using it under the terms of the CERN-OHL-S v2 (https:/cern.ch/cern-ohl).  #
#           This Source is distributed WITHOUT ANY EXPRESS OR IMPLIED          #
#    WARRANTY, INCLUDING OF MERCHANTABILITY, SATISFACTORY QUALITY AND FITNESS  #
#     FOR A PARTICULAR PURPOSE. Please see the CERN-OHL-S v2 for applicable    #
#                                  conditions.                                 #
#                                                                              #
#                Source location: https://github.com/buildbotics               #
#                                                                              #
#      As per CERN-OHL-S v2 section 4, should You produce hardware based on    #
#    these sources, You must maintain the Source Location clearly visible on   #
#    the external case of the CNC Controller or other product you make using   #
#                                  this Source.                                #
#                                                                              #
#                For more information, email info@buildbotics.com              #
#                                                                              #
################################################################################

import subprocess

from .LCDPage import *

__all__ = ['InputsPage']


class InputsPage(LCDPage):
    # From LCDPage
    def activate(self):
        state = self.lcd.ctrl.state

        self.clear()

        self.text('0123', 5, 0)
        self.text('Min:', 0, 1)
        self.text('Max:', 0, 2)

        for i in range(4):
            minSwitch = state.get('min-switch-' + i)
            maxSwitch = state.get('max-switch-' + i)

            self.text(' ', 5 + i, 1)
            self.text(' ', 5 + i, 2)
